﻿import QtQuick 2.5
import QtQuick.Controls 1.4
import QtQuick.Layouts 1.2

Item {
    id: item1
    width: 640
    height: 480

    property alias image1: image1
    property alias mouseArea1: mouseArea1
    property alias tabView1: tabView1
    property alias drawTool: drawTool
    property alias selectTool: selectTool
    property alias copyTool: copyTool
    property alias cutTool: cutTool
    property alias pasteTool: pasteTool
    property alias tTypeValue: tTypeValue
    property alias wTypeValue: wTypeValue

    ScrollView {
        anchors.right: columnLayout1.left
        anchors.rightMargin: 6
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.bottom: rectangle.top
        anchors.bottomMargin: 0
        anchors.top: parent.top
        anchors.topMargin: 8
        highlightOnFocus: false
        verticalScrollBarPolicy: 0
        horizontalScrollBarPolicy: 0
        frameVisible: true

        Image {
            id: image1
            fillMode: Image.Pad
            cache: false
            clip: true
            horizontalAlignment: Image.AlignLeft
            verticalAlignment: Image.AlignTop
            source: "image://myimageprovider/0"

            MouseArea {
                id: mouseArea1
                anchors.fill: parent
                hoverEnabled: true
                acceptedButtons: Qt.LeftButton | Qt.RightButton
            }
        }
    }


    Rectangle {
        id: rectangle
        y: 446
        height: cursorInfos.height + 8
        color: "#00000000"
        border.color: "#808080"
        border.width: 1
        anchors.right: columnLayout1.left
        anchors.rightMargin: 6
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8

        Label {
            id: cursorInfos
            x: 0
            y: 187
            text: bridge.cursorInfo
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 4
            anchors.left: parent.left
            anchors.leftMargin: 4
            anchors.right: parent.right
            anchors.rightMargin: 4
        }
    }

    TabView {
        id: tabView1
        height: item1.height / 2 - y
        tabsVisible: true
        frameVisible: true
        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8

        Tab {
            id:mapTab
            title: qsTr("Map")
            source:"/MapTab.qml"
        }

        Tab {
            id:tilesTab
            title: qsTr("Cases")
            source:"/TilesTab.qml"
        }

        Tab {
            id:wallsTab
            title: qsTr("Murs")
            source:"/WallsTab.qml"
        }

        Tab {
            title: qsTr("Objets")
        }
    }

    Column {
        id: columnLayout1
        spacing: 3
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: tabView1.left
        anchors.rightMargin: 8
        enabled: tabView1.currentIndex != 0

        Button {
            id: drawTool
            width: 38
            height: 38
            checkable: true
            checked: true

            Image
            {
                opacity: (drawTool.enabled ? 1.0 : 0.5)
                source: "gfx/pencil.png"
                anchors.fill: parent
                anchors.margins: 4
            }
        }

        Button {
            id: selectTool
            width: 38
            height: 38
            Image {
                source: "gfx/select.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
            checkable: true
        }

        Button {
            id: copyTool
            width: 38
            height: 38
            Image {
                source: "gfx/copy.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
        }

        Button {
            id: cutTool
            width: 38
            height: 38
            Image {
                source: "gfx/cut.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
        }

        Button {
            id: pasteTool
            width: 38
            height: 38
            Image {
                source: "gfx/paste.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
            checkable: true
        }
    }

    GroupBox {
        id: selectionBox
        x: 403
        width: tabView1.width
        anchors.top: tabView1.bottom
        anchors.topMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.right: parent.right
        anchors.rightMargin: 8
        title: qsTr("Sélection")

        ScrollView {
            id: tileSelScroll
            visible: bridge.tileSelScrollVis
            anchors.fill: parent

            GridLayout {
                id: tSelGrid
                objectName: "tSelGrid"
                rowSpacing: 4
                columnSpacing: 4
                rows: 3
                columns: 2
                anchors.fill: parent

                Label {
                    id: tPosLabel
                    height: 20
                    text: qsTr("Position:")
                    verticalAlignment: Text.AlignVCenter
                    renderType: Text.QtRendering
                }

                Label {
                    id: tPosValue
                    height: 20
                    text: bridge.selPosition
                    verticalAlignment: Text.AlignVCenter
                }

                Label {
                    id: tTypeLabel
                    height: 20
                    text: qsTr("Type:")
                    verticalAlignment: Text.AlignVCenter
                    horizontalAlignment: Text.AlignLeft
                }

                ComboBox {
                    id: tTypeValue
                    model: tilesList
                    currentIndex: bridge.selTileType
                }
            }

        }

        ScrollView {
            id: wallSelScroll
            visible: bridge.wallSelScrollVis
            anchors.fill: parent

            GridLayout {
                id: wSelGrid
                objectName: "wSelGrid"
                rowSpacing: 4
                columnSpacing: 4
                rows: 3
                columns: 2
                anchors.fill: parent

                Label {
                    id: wPosLabel
                    height: 20
                    text: qsTr("Position:")
                    verticalAlignment: Text.AlignVCenter
                    renderType: Text.QtRendering
                }

                Label {
                    id: wPosValue
                    height: 20
                    text: bridge.selPosition
                    verticalAlignment: Text.AlignVCenter
                }

                Label {
                    id: wTypeLabel
                    height: 20
                    text: qsTr("Type:")
                    verticalAlignment: Text.AlignVCenter
                    horizontalAlignment: Text.AlignLeft
                }

                ComboBox {
                    id: wTypeValue
                    model: wallsList
                    currentIndex: bridge.selWallType
                }
            }
        }

        ScrollView {
            id: objectSelScroll
            visible: bridge.objectSelScrollVis
            anchors.fill: parent

            GridLayout {
                id: oSelGrid
                objectName: "oSelGrid"
                rowSpacing: 4
                columnSpacing: 4
                rows: 3
                columns: 2
                anchors.fill: parent

                Label {
                    id: oPosLabel
                    height: 20
                    text: qsTr("Position:")
                    verticalAlignment: Text.AlignVCenter
                    renderType: Text.QtRendering
                }

                Label {
                    id: oPosValue
                    height: 20
                    text: bridge.selPosition
                    verticalAlignment: Text.AlignVCenter
                }
            }

        }

        ScrollView {
            id: rectSelScroll
            visible: bridge.rectSelScrollVis
            anchors.fill: parent

            GridLayout {
                id: rSelGrid
                objectName: "rSelGrid"
                rowSpacing: 4
                columnSpacing: 4
                rows: 3
                columns: 2
                anchors.fill: parent

                Label {
                    id: rPosLabel
                    height: 20
                    text: qsTr("Position:")
                    verticalAlignment: Text.AlignVCenter
                    renderType: Text.QtRendering
                }

                Label {
                    id: rPosValue
                    height: 20
                    text: bridge.selPosition
                    verticalAlignment: Text.AlignVCenter
                }

                Label {
                    id: rSizeLabel
                    height: 20
                    text: qsTr("Taille:")
                    verticalAlignment: Text.AlignVCenter
                    renderType: Text.QtRendering
                }

                Label {
                    id: rSizeValue
                    height: 20
                    text: bridge.selSize
                    verticalAlignment: Text.AlignVCenter
                }
            }

        }
    }


}

