﻿#include <QApplication>
#include <QQmlApplicationEngine>
#include <QQmlContext>
#include "bridge.h"
#include "keyboard.h"
#include "../common/sources/Map.h"
#include "player.h"
#include "tiles.h"
#include "walls.h"
#include "interface.h"
#include "character.h"

QQmlContext     *ctxt;

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QQmlApplicationEngine engine;

    // lit les bases de données
    interface.readTextDB();
    tiles.readFloorOrnatesDB();
    tiles.readTilesDB();
    walls.readOrnatesDB();
    walls.readWallsDB();
    CCharacter::readCharactersDB();

    // enregistre nos fonctions
    ctxt = engine.rootContext();
    ctxt->setContextProperty("bridge", &bridge);

    // enregistre l'ImageProvider
    engine.addImageProvider("myimageprovider", new MyImageProvider);

    map.load((char *)"maps/level01.map");
    player.pos.x = 1;
    player.pos.y = 3;
    player.dir = 2;

    // lance l'interface
    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));

	// enregistre l'EventFilter pour le clavier
    QApplication::instance()->installEventFilter(&keyboard);

    int retValue = app.exec();

	// désenregistre l'EventFilter
    QApplication::instance()->removeEventFilter(&keyboard);

    return retValue;
}

